@@ -2,4 +2,4 @@ from django.db import models
 
 class ModelDictModel(models.Model):
     key = models.CharField(max_length=32, unique=True)
-    value = models.CharField(max_length=32)
\ No newline at end of file
+    value = models.CharField(max_length=32, default='')
\ No newline at end of file
